==> unixODBC-1.8.8.tar.gz: unixODBC-1.8.8/sqi/_sqiNewColumnHeader.c <==
#include "sqi.h"


HSQICOLUMN _sqiNewColumnHeader( int nCol, char *pszCatalogFile, char *pszTableName, char *pszColumnName )
{
    HSQICOLUMN pColumnHeader = malloc( sizeof(SQICOLUMN) );

	pColumnHeader->nCol		= nCol;

    /* IS AUTO INCREMENT COL?					*/
	pColumnHeader->bSQL_DESC_AUTO_UNIQUE_VALUE = 0;

    /* empty string if N/A						*/
	pColumnHeader->pszSQL_DESC_BASE_COLUMN_NAME = ( pszColumnName ? (char*)strdup( pszColumnName ) : (char*)strdup( "Unknown" ) );

    /* empty string if N/A						*/
	pColumnHeader->pszSQL_DESC_BASE_TABLE_NAME = ( pszTableName ? (char*)strdup( pszTableName ) : (char*)strdup( "Unknown" ) );

    /* IS CASE SENSITIVE COLUMN?				*/
	pColumnHeader->bSQL_DESC_CASE_SENSITIVE = 0;

    /* empty string if N/A						*/
	pColumnHeader->pszSQL_DESC_CATALOG_NAME = ( pszCatalogFile ? (char*)strdup( pszCatalogFile ) : (char*)strdup( "Unknown" ) );

    /* ie SQL_CHAR, SQL_TYPE_TIME...			*/
	pColumnHeader->nSQL_DESC_CONCISE_TYPE = SQL_VARCHAR;

    /* max digits required to display			*/
	pColumnHeader->nSQL_DESC_DISPLAY_SIZE = 255;

    /* has data source specific precision?		*/
	pColumnHeader->bSQL_DESC_FIXED_PREC_SCALE = 0;

    /* display label, col name or empty string	*/
	pColumnHeader->pszSQL_DESC_LABEL = ( pszColumnName ? (char*)strdup( pszColumnName ) : (char*)strdup( "Unknown" ) );

    /* strlen or bin size						*/
	pColumnHeader->nSQL_DESC_LENGTH = 255;

    /* empty string if N/A						*/
	pColumnHeader->pszSQL_DESC_LITERAL_PREFIX = (char*)strdup( "" );

    /* empty string if N/A						*/
	pColumnHeader->pszSQL_DESC_LITERAL_SUFFIX = (char*)strdup( "" );			

    /* empty string if N/A						*/
	pColumnHeader->pszSQL_DESC_LOCAL_TYPE_NAME = (char*)strdup( "" );

    /* col alias, col name or empty string		*/
	pColumnHeader->pszSQL_DESC_NAME = ( pszColumnName ? (char*)strdup( pszColumnName ) : (char*)strdup( "Unknown" ) );

    /* SQL_NULLABLE, _NO_NULLS or _UNKNOWN		*/
	pColumnHeader->nSQL_DESC_NULLABLE = SQL_NO_NULLS;

    /* 2, 10, or if N/A... 0 					*/
	pColumnHeader->nSQL_DESC_NUM_PREC_RADIX = 0;

    /* max size									*/
	pColumnHeader->nSQL_DESC_OCTET_LENGTH = 255;

    /*											*/
	pColumnHeader->nSQL_DESC_PRECISION = 4;

    /*											*/
	pColumnHeader->nSQL_DESC_SCALE = 4;

    /* empty string if N/A						*/
	pColumnHeader->pszSQL_DESC_SCHEMA_NAME = (char*)strdup( "" );

    /* can be in a filter ie SQL_PRED_NONE...	*/
	pColumnHeader->nSQL_DESC_SEARCHABLE = SQL_PRED_SEARCHABLE;

    /* empty string if N/A						*/
	pColumnHeader->pszSQL_DESC_TABLE_NAME = ( pszTableName ? (char*)strdup( pszTableName ) : (char*)strdup( "Unknown" ) );

    /* SQL data type ie SQL_CHAR, SQL_INTEGER..	*/
	pColumnHeader->nSQL_DESC_TYPE = SQL_VARCHAR;

    /* DBMS data type ie VARCHAR, MONEY...		*/
	pColumnHeader->pszSQL_DESC_TYPE_NAME = (char*)strdup( "VARCHAR" );

    /* qualifier for SQL_DESC_NAME ie SQL_NAMED	*/
	pColumnHeader->nSQL_DESC_UNNAMED = SQL_NAMED;

    /* if signed FALSE else TRUE				*/
	pColumnHeader->bSQL_DESC_UNSIGNED = 0;

    /* ie SQL_ATTR_READONLY, SQL_ATTR_WRITE...	*/
	pColumnHeader->nSQL_DESC_UPDATABLE = SQL_ATTR_READONLY;
	
	pColumnHeader->bPimaryKey = false;

	return pColumnHeader;
}

==> unixODBC-1.8.13.tar.gz: unixODBC-1.8.13/sqi/_sqiNewColumnHeader.c <==
#include "sqi.h"


HSQICOLUMN _sqiNewColumnHeader( int nCol, char *pszDatabase, char *pszTableName, char *pszColumnName, int nType, int nSize )
{
    HSQICOLUMN pColumnHeader = malloc( sizeof(SQICOLUMN) );

	pColumnHeader->nCol		= nCol;

    /* IS AUTO INCREMENT COL?					*/
	pColumnHeader->bSQL_DESC_AUTO_UNIQUE_VALUE = 0;

    /* empty string if N/A						*/
	pColumnHeader->pszSQL_DESC_BASE_COLUMN_NAME = ( pszColumnName ? (char*)strdup( pszColumnName ) : (char*)strdup( "Unknown" ) );

    /* empty string if N/A						*/
	pColumnHeader->pszSQL_DESC_BASE_TABLE_NAME = ( pszTableName ? (char*)strdup( pszTableName ) : (char*)strdup( "Unknown" ) );

    /* IS CASE SENSITIVE COLUMN?				*/
	pColumnHeader->bSQL_DESC_CASE_SENSITIVE = 0;

    /* empty string if N/A						*/
	pColumnHeader->pszSQL_DESC_CATALOG_NAME = ( pszDatabase ? (char*)strdup( pszDatabase ) : (char*)strdup( "Unknown" ) );

    /* ie SQL_CHAR, SQL_TYPE_TIME...			*/
	pColumnHeader->nSQL_DESC_CONCISE_TYPE = nType; /* SQL_VARCHAR; */

    /* max digits required to display			*/
	pColumnHeader->nSQL_DESC_DISPLAY_SIZE = nSize;

    /* has data source specific precision?		*/
	pColumnHeader->bSQL_DESC_FIXED_PREC_SCALE = 0;

    /* display label, col name or empty string	*/
	pColumnHeader->pszSQL_DESC_LABEL = ( pszColumnName ? (char*)strdup( pszColumnName ) : (char*)strdup( "Unknown" ) );

    /* strlen or bin size						*/
	pColumnHeader->nSQL_DESC_LENGTH = nSize;

    /* empty string if N/A						*/
	pColumnHeader->pszSQL_DESC_LITERAL_PREFIX = (char*)strdup( "" );

    /* empty string if N/A						*/
	pColumnHeader->pszSQL_DESC_LITERAL_SUFFIX = (char*)strdup( "" );			

    /* empty string if N/A						*/
	pColumnHeader->pszSQL_DESC_LOCAL_TYPE_NAME = (char*)strdup( "" );

    /* col alias, col name or empty string		*/
	pColumnHeader->pszSQL_DESC_NAME = ( pszColumnName ? (char*)strdup( pszColumnName ) : (char*)strdup( "Unknown" ) );

    /* SQL_NULLABLE, _NO_NULLS or _UNKNOWN		*/
	pColumnHeader->nSQL_DESC_NULLABLE = SQL_NO_NULLS;

    /* 2, 10, or if N/A... 0 					*/
	pColumnHeader->nSQL_DESC_NUM_PREC_RADIX = 0;

    /* max size									*/
	pColumnHeader->nSQL_DESC_OCTET_LENGTH = 255;

    /*											*/
	pColumnHeader->nSQL_DESC_PRECISION = 4;

    /*											*/
	pColumnHeader->nSQL_DESC_SCALE = 4;

    /* empty string if N/A						*/
	pColumnHeader->pszSQL_DESC_SCHEMA_NAME = (char*)strdup( "" );

    /* can be in a filter ie SQL_PRED_NONE...	*/
	pColumnHeader->nSQL_DESC_SEARCHABLE = SQL_PRED_SEARCHABLE;

    /* empty string if N/A						*/
	pColumnHeader->pszSQL_DESC_TABLE_NAME = ( pszTableName ? (char*)strdup( pszTableName ) : (char*)strdup( "Unknown" ) );

    /* SQL data type ie SQL_CHAR, SQL_INTEGER..	*/
	pColumnHeader->nSQL_DESC_TYPE = SQL_VARCHAR;

    /* DBMS data type ie VARCHAR, MONEY...		*/
	pColumnHeader->pszSQL_DESC_TYPE_NAME = (char*)strdup( "VARCHAR" );

    /* qualifier for SQL_DESC_NAME ie SQL_NAMED	*/
	pColumnHeader->nSQL_DESC_UNNAMED = SQL_NAMED;

    /* if signed FALSE else TRUE				*/
	pColumnHeader->bSQL_DESC_UNSIGNED = 0;

    /* ie SQL_ATTR_READONLY, SQL_ATTR_WRITE...	*/
	pColumnHeader->nSQL_DESC_UPDATABLE = SQL_ATTR_READONLY;
	
	pColumnHeader->bPimaryKey = false;

	return pColumnHeader;
}
